summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorAlexander Ponyatykh <lazyranma@gmail.com>2019-11-24 02:20:04 +0300
committerAlexander Ponyatykh <lazyranma@gmail.com>2019-11-24 01:02:32 +0100
commit1eb60368789455681e619240aa2dad97bcdefa97 (patch)
treeb06d5781caf02f5abd2a52e481365941f53f9dc1
parentd59d8bac203de36a953a678b22694a1c885deffc (diff)
Gbp-Pq: Name 0002-fix-spelling.patch
-rw-r--r--paargs/paargs.pod4
-rw-r--r--paexec/paexec.c4
-rw-r--r--paexec/paexec.pod2
-rw-r--r--paexec/paexec_reorder.pod2
-rw-r--r--paexec/tasks.c2
-rwxr-xr-xtests/test.sh10
6 files changed, 12 insertions, 12 deletions
diff --git a/paargs/paargs.pod b/paargs/paargs.pod
index dd9e305..bad231f 100644
--- a/paargs/paargs.pod
+++ b/paargs/paargs.pod
@@ -26,7 +26,7 @@ I<-x> -- for being B<xargs>-like,
=item *
I<-l> -- 0-based task number is included to the output of B<paargs>, this
-allows to reorder the sliced output,
+allows one to reorder the sliced output,
=item *
@@ -79,7 +79,7 @@ Passed directly to B<paexec>.
=item B<-f>
-Flushes stdout after recieving an end-of-task line.
+Flushes stdout after receiving an end-of-task line.
=item B<-0>
diff --git a/paexec/paexec.c b/paexec/paexec.c
index 6558f6f..b2ae5cf 100644
--- a/paexec/paexec.c
+++ b/paexec/paexec.c
@@ -96,7 +96,7 @@ OPTIONS:\n\
-d debug mode, for debugging only\n\
\n\
-z failed nodes are marked as dead\n\
- -Z <timeout> timeout to restart faild command, imply -z\n\
+ -Z <timeout> timeout to restart failed command, imply -z\n\
-w wait for restoring nodes (needs -Z)\n\
\n\
-W heavier tasks are processed first, a weight\n\
@@ -627,7 +627,7 @@ void wait_for_childs (void)
return;
if (debug)
- printf ("wait for childs\n");
+ printf ("wait for children\n");
for (i=0; i < nodes_count; ++i){
if (pids [i] != (pid_t) -1){
diff --git a/paexec/paexec.pod b/paexec/paexec.pod
index 62a15d3..feae47b 100644
--- a/paexec/paexec.pod
+++ b/paexec/paexec.pod
@@ -274,7 +274,7 @@ during the current run of paexec.
When I<-z> applied, if a I<command> fails, appropriate node is marked
as broken and is excluded from the following task distribution. But if
-B<-Z> applied, every I<timeout> seconds an attempt to rerun a comand
+B<-Z> applied, every I<timeout> seconds an attempt to rerun a command
on a failed node is made. I<-Z> implies I<-z>. This option makes
possible to organize clusters over unreliable networks/hardware.
diff --git a/paexec/paexec_reorder.pod b/paexec/paexec_reorder.pod
index e44a6eb..90af230 100644
--- a/paexec/paexec_reorder.pod
+++ b/paexec/paexec_reorder.pod
@@ -11,7 +11,7 @@ B<paexec_reorder> [I<OPTIONS>] [I<files...>]
B<paexec> with -l option produces a sliced output where results of
different tasks are intermixed. The intent of B<paexec_reorder> is to
produce ordered output where results for all tasks follow each other
-without intermixing. It is strongly recomended to send output of
+without intermixing. It is strongly recommended to send output of
"B<paexec> I<-le>" or "B<paexec> I<-gle>" to the input of B<paexec_reorder>. Otherwise
more memory or disk space for temporary files will be required.
diff --git a/paexec/tasks.c b/paexec/tasks.c
index 42ecdb3..821ff58 100644
--- a/paexec/tasks.c
+++ b/paexec/tasks.c
@@ -368,7 +368,7 @@ static void check_cycles__outgoing (int stack_sz)
switch (check_cycles__mark [to]){
case 2:
loop = 0;
- fprintf (stderr, "Cyclic dependancy detected:\n");
+ fprintf (stderr, "Cyclic dependency detected:\n");
for (j=1; j <= stack_sz; ++j){
s = check_cycles__stack [j-1];
t = check_cycles__stack [j];
diff --git a/tests/test.sh b/tests/test.sh
index 4db4a32..40a53d9 100755
--- a/tests/test.sh
+++ b/tests/test.sh
@@ -2016,7 +2016,7 @@ ok21
ok100
'
# diamond-like dependancy and failure
runtest -l -s -C -n +5 cmd_xxx_failed_make_package flex \
> $OBJDIR/_test.tmp < ../examples/make_package/tasks2
@@ -2044,7 +2044,7 @@ ok
-c cmd_make_package \
-n +5 < ../examples/make_package/tasks_cycle |
cmp 'paexec cyclic deps #1' \
-'Cyclic dependancy detected:
+'Cyclic dependency detected:
devel/gettext-lib -> devel/gmake
devel/gmake -> lang/gcc
lang/gcc -> devel/gettext-lib
@@ -2061,7 +2061,7 @@ task30 task10
-c cmd_make_package \
-n +5 |
cmp 'paexec cyclic deps #2' \
-'Cyclic dependancy detected:
+'Cyclic dependency detected:
task10 -> task20
task20 -> task30
task30 -> task10
@@ -2077,7 +2077,7 @@ task30 task40
-c cmd_make_package \
-n +5 |
cmp 'paexec cyclic deps #3' \
-'Cyclic dependancy detected:
+'Cyclic dependency detected:
task50 -> task50
'
@@ -2096,7 +2096,7 @@ task300 task0
-c cmd_make_package \
-n +5 |
cmp 'paexec cyclic deps #4' \
-'Cyclic dependancy detected:
+'Cyclic dependency detected:
task0 -> task200
task200 -> task300
task300 -> task0
@@ -2016,7 +2016,7 @@ ok21
ok100
'
- # diamond-like dependancy and failure
+ # diamond-like dependency and failure
runtest -l -s -C -n +5 cmd_xxx_failed_make_package flex \
> $OBJDIR/_test.tmp < ../examples/make_package/tasks2